PyXMake Developer Guide: PyXMake.Build.Make Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Classes | Variables
PyXMake.Build.Make Namespace Reference

Create a make object to define the building environment. More...

## Classes
class | CCxx
| Base class for all C/C++ build events inherited from Make. More...
class | Coverage
| Base class for all Coverage build events. More...
class | Custom
| Base class for all custom build events inherited from Make. More...
class | Doxygen
| Base class for all Doxygen build events. More...
class | Fortran
| Base class for all Fortran build events. More...
class | Latex
| Base class for all Latex build events. More...
class | Make
| Abstract base class for all make objects. More...
class | NSIS
| Base class for all NSIS build events. More...
class | NT
| Abstract base class for all NT subclasses. More...
class | OS
| Abstract base class for all system subclasses. More...
class | POSIX
| Abstract base class for all POSIX subclasses. More...
class | Py2X
| Base class for all Py2X (for now only f2py) build events. More...
class | PyInstaller
| Base class for all PyInstaller build events. More...
class | PyReq
| Base class for all PyReq build events. More...
class | Sphinx
| Base class for all Sphinx build events. More...
class | SSH
| Base class for all build events requiring a SSH connection. More...

## Variables
| FileNotFoundError = IOError
| PyXMakePath = Utility.GetPyXMakePath()
| Absolute system path to PyXMake.
| Path2Config = os.path.join(PyXMakePath,"Build","config")
| Absolute system path to configuration files.
| AllowDefaultMakeOption = bool(int("-1" if __debug__ or not getattr(sys,"frozen",False) else int(os.getenv("pyx_default_make_opt","0"))) == -1)
| logger = logging.getLogger(__name__)
| Create an alias using default logger for all print statements.

## Detailed Description

Create a make object to define the building environment.

    Create a make object to define the building environment and to execute the
    build commands. The make event is subdivided in a pre-, main- and a post-build
    event.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018

## Variable Documentation

## ◆ AllowDefaultMakeOption

PyXMake.Build.Make.AllowDefaultMakeOption = bool(int("-1" if __debug__ or not getattr(sys,"frozen",False) else int(os.getenv("pyx_default_make_opt","0"))) == -1)

Definition at line 95 of file Make.py.

## ◆ FileNotFoundError

PyXMake.Build.Make.FileNotFoundError = IOError

Definition at line 41 of file Make.py.

## ◆ logger

PyXMake.Build.Make.logger = logging.getLogger(__name__)

Create an alias using default logger for all print statements.

Definition at line 98 of file Make.py.

## ◆ Path2Config

PyXMake.Build.Make.Path2Config = os.path.join(PyXMakePath,"Build","config")

Absolute system path to configuration files.

Definition at line 93 of file Make.py.

## ◆ PyXMakePath

PyXMake.Build.Make.PyXMakePath = Utility.GetPyXMakePath()

Absolute system path to PyXMake.

Definition at line 91 of file Make.py.